==> gucharmap-2.21.4.tar.gz: gucharmap-2.21.4/gucharmap/gucharmap-marshal.h <==

#ifndef ___gucharmap_marshal_MARSHAL_H__
#define ___gucharmap_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:UINT,UINT (./gucharmap-marshal.list:3) */
G_GNUC_INTERNAL void _gucharmap_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (./gucharmap-marshal.list:4) */
G_GNUC_INTERNAL void _gucharmap_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* BOOLEAN:ENUM,INT (./gucharmap-marshal.list:5) */
G_GNUC_INTERNAL void _gucharmap_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

G_END_DECLS

#endif /* ___gucharmap_marshal_MARSHAL_H__ */

==> gucharmap_2.24.1.orig.tar.gz: gucharmap-2.24.1/gucharmap/gucharmap-marshal.h <==

#ifndef ___gucharmap_marshal_MARSHAL_H__
#define ___gucharmap_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:UINT,UINT (../../gucharmap/gucharmap-marshal.list:1) */
G_GNUC_INTERNAL void _gucharmap_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (../../gucharmap/gucharmap-marshal.list:2) */
G_GNUC_INTERNAL void _gucharmap_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* BOOLEAN:ENUM,INT (../../gucharmap/gucharmap-marshal.list:3) */
G_GNUC_INTERNAL void _gucharmap_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

G_END_DECLS

#endif /* ___gucharmap_marshal_MARSHAL_H__ */
